@@ -80,6 +80,11 @@ class PunctSplitEntry(ResourceEntry):
         self.group = group if group else False
 
 
+class NonSymbolEntry(ResourceEntry):
+    def __init__(self, s: str):
+        super().__init__(s)
+
+
 class ResourceDict:
     def __init__(self):
         """Dictionary of ResourceEntries. All dictionary keys are lower case."""
@@ -144,6 +149,17 @@ class ResourceDict:
                         for repl_char in repl_chars:
                             new_line = f'{m3.group(1)}{regex.sub(apostrophe, repl_char, m3.group(2))}{m3.group(3)}'
                             lines.append(new_line)
+        # expand resource entry with hyphen to alternatives with closely related characters (e.g. Armenian hyphen)
+        hyphen = "-"
+        n_lines = len(lines)
+        for line in lines[0:n_lines]:
+            if hyphen in line:
+                repl_chars = "–֊"  # en-dash, Aramenian hyphen
+                if (repl_chars != '') and (m3 := regex.match(r'(::\S+\s+)(\S|\S.*?\S)(\s+::\S.*|\s*)$', line)):
+                    if hyphen in m3.group(2):
+                        for repl_char in repl_chars:
+                            new_line = f'{m3.group(1)}{regex.sub(hyphen, repl_char, m3.group(2))}{m3.group(3)}'
+                            lines.append(new_line)
         # expand resource entry with ::plural
         n_lines = len(lines)
         for line in lines[0:n_lines]:
@@ -298,6 +314,7 @@ class ResourceDict:
                                                                               'left-context-not',
                                                                               'lexical',
                                                                               'misspelling',
+                                                                              'non-symbol',
                                                                               'nonstandard',
                                                                               'plural',
                                                                               'problem',
@@ -319,6 +336,7 @@ class ResourceDict:
                                                                                      'contraction': ['target'],
                                                                                      'lexical': [],
                                                                                      'misspelling': ['target'],
+                                                                                     'non-symbol': [],
                                                                                      'punct-split': ['side'],
                                                                                      'repair': ['target']})
                         if not valid:
@@ -377,6 +395,8 @@ class ResourceDict:
                             target = slot_value_in_double_colon_del_list(line, 'target')
                             resource_entry = RepairEntry(s, target)
                             self.register_resource_entry_in_reverse_resource_dict(resource_entry, [target])
+                        elif head_slot == 'non-symbol':
+                            resource_entry = NonSymbolEntry(s)
                         if resource_entry:  # register resource_entry with lowercase key
                             if len(s) > self.max_s_length:
                                 self.max_s_length = len(s)
@@ -452,13 +472,15 @@ class ResourceDict:
 
 
 class DetokenizationEntry:
-    def __init__(self, s: str, group: Optional[bool] = False, lang_codes: List[str] = None,
+    def __init__(self, s: str, group: Optional[bool] = False,
+                 lang_codes: List[str] = None, lang_codes_not: List[str] = None,
                  left_context: Optional[Pattern[str]] = None, left_context_not: Optional[Pattern[str]] = None,
                  right_context: Optional[Pattern[str]] = None, right_context_not: Optional[Pattern[str]] = None,
                  case_sensitive: bool = False):
         self.s = s
         self.group = group
         self.lang_codes = lang_codes
+        self.lang_codes_not = lang_codes_not
         self.left_context: Optional[Pattern[str]] = left_context
         self.left_context_not: Optional[Pattern[str]] = left_context_not
         self.right_context: Optional[Pattern[str]] = right_context
@@ -469,7 +491,9 @@ class DetokenizationEntry:
                                                  lang_code: Optional[str], group: Optional[bool] = False) -> bool:
         """This methods checks whether a detokenization-entry satisfies any context conditions."""
         lang_codes = self.lang_codes
+        lang_codes_not = self.lang_codes_not
         return ((not lang_code or not lang_codes or (lang_code in lang_codes))
+                and (not lang_code or not lang_codes_not or (lang_code not in lang_codes_not))
                 and (not self.case_sensitive or (token == self.s))
                 and (not group or self.group)
                 and (not (re_l := self.left_context) or re_l.match(left_context))
@@ -558,6 +582,7 @@ class DetokenizationResource:
                                                                               'lexical',
                                                                               'markup-attach',
                                                                               'misspelling',
+                                                                              'non-symbol',
                                                                               'nonstandard',
                                                                               'paired-delimiter',
                                                                               'plural',
@@ -576,7 +601,8 @@ class DetokenizationResource:
                                                                                      'auto-attach': ['side'],
                                                                                      'contraction': ['target'],
                                                                                      'lexical': [],
-                                                                                     'markup-attach': []})
+                                                                                     'markup-attach': [],
+                                                                                     'non-symbol': []})
                         if not valid:
                             n_warnings += 1
                             continue
@@ -674,6 +700,8 @@ class DetokenizationResource:
                                 except regex.error:
                                     log.warning(f'Regex compile error in l.{line_number} for {s} ::right-context-not '
                                                 f'{right_context_not_s}')
+                            if lang_code_not_s := slot_value_in_double_colon_del_list(line, 'lcode-not'):
+                                detokenization_entry.lang_codes_not = re.split(r'[;,\s*]', lang_code_not_s)
                             n_entries += 1
                 if verbose:
                     log.info(f'Loaded {n_entries} entries from {line_number} lines in {filename}')
